import { AbstractControl, FormGroup } from '@angular/forms';
import { Subject, Subscription } from 'rxjs';
export interface StoreFormBinding {
    path: string;
    formGroup: FormGroup;
    formGroupSubscription: Subscription;
    storeSubscription?: Subscription;
    stateUpdateTrigger: Subject<never>;
}
export interface ErrorMessages {
    [k: string]: ErrorMessages | string;
}
export declare type ErrorResolver = (control: AbstractControl, path: string[]) => string[] | null;
export interface ResolvedErrorMessages {
    [k: string]: ResolvedErrorMessages | string[];
}
export declare type StoreFormsBindingStrategy = 'ObserveStore' | 'OnlyUpdateStoreFormAction';
export interface StoreFormsConfig {
    bindingStrategy?: StoreFormsBindingStrategy;
    errorMessages?: ErrorMessages;
    debounce?: number;
}
export interface FormControlStateBase {
    untouched?: boolean;
    touched?: boolean;
    pristine?: boolean;
    dirty?: boolean;
    valid?: boolean;
    invalid?: boolean;
    pending?: boolean;
    disabled?: boolean;
    enabled?: boolean;
}
export declare type FormGroupValues<F> = {
    [k in keyof F]: FormGroupValues<F[k]> | string;
};
export declare type FormGroupFields<F> = {
    [k in keyof F]: FormGroupState<F[k]> | FormControlState;
};
export interface FormGroupState<F = any> extends FormControlStateBase {
    value?: FormGroupValues<F>;
    errors?: string[];
    fields?: FormGroupFields<F>;
}
export interface FormControlState extends FormControlStateBase {
    value?: string;
    errors?: string[];
}
